@@ -1112,7 +1112,7 @@ class WordToken(caching.base.CachingMixin,models.Model):
             if 'W' in form['lexical_scale'] and 'BuckeyeSPhoneProb' not in outline:
                 outline['BuckeyeSPhoneProb'],outline['BuckeyeBiPhoneProb'] = self.WordType.getPhonoProb()
             if 'S' in form['lexical_scale'] and 'SpeakerSPhoneProb' not in outline:
-                qs = WordToken.objects.filter(Dialog__Speaker= self.Speaker).filter(WordType=self.WordType).order_by('Dialog')
+                qs = WordToken.objects.filter(Dialog__Speaker= self.Dialog.Speaker).filter(WordType=self.WordType).order_by('Dialog')
                 for q in qs:
                     if 'SpeakerSPhoneProb' in q.Output:
                         outline['SpeakerSPhoneProb'],outline['SpeakerBiPhoneProb'] = q.Output['SpeakerSPhoneProb'],q.Output['SpeakerBiPhoneProb']
@@ -1120,7 +1120,7 @@ class WordToken(caching.base.CachingMixin,models.Model):
                 else:
                     outline['SpeakerSPhoneProb'],outline['SpeakerBiPhoneProb'] = self.WordType.getPhonoProb(subset='speaker',speaker=self.Dialog.Speaker)
             if 'A' in form['lexical_scale'] and 'AgeSPhoneProb' not in outline:
-                qs = WordToken.objects.filter(Dialog__Speaker__Age= self.Speaker.Age).filter(WordType=self.WordType).order_by('Dialog')
+                qs = WordToken.objects.filter(Dialog__Speaker__Age= self.Dialog.Speaker.Age).filter(WordType=self.WordType).order_by('Dialog')
                 for q in qs:
                     if 'AgeSPhoneProb' in q.Output:
                         outline['AgeSPhoneProb'],outline['AgeBiPhoneProb'] = q.Output['AgeSPhoneProb'],q.Output['AgeBiPhoneProb']
@@ -1128,7 +1128,7 @@ class WordToken(caching.base.CachingMixin,models.Model):
                 else:
                     outline['AgeSPhoneProb'],outline['AgeBiPhoneProb'] = self.WordType.getPhonoProb(subset='age',speaker=self.Dialog.Speaker)
             if 'G' in form['lexical_scale'] and 'GenderSPhoneProb' not in outline:
-                qs = WordToken.objects.filter(Dialog__Speaker__Gender= self.Speaker.Gender).filter(WordType=self.WordType).order_by('Dialog')
+                qs = WordToken.objects.filter(Dialog__Speaker__Gender= self.Dialog.Speaker.Gender).filter(WordType=self.WordType).order_by('Dialog')
                 for q in qs:
                     if 'GenderSPhoneProb' in q.Output:
                         outline['GenderSPhoneProb'],outline['GenderBiPhoneProb'] = q.Output['GenderSPhoneProb'],q.Output['GenderBiPhoneProb']
